"""Annotated types for virtual identifiers such as :term:`VLAN` ID or Virtual Circuit ID."""

from typing import Annotated

from pydantic import Field
from typing_extensions import Doc

VLAN_ID = Annotated[int, Field(gt=0, lt=4096)]
VC_ID = Annotated[
    int,
    Field(gt=0, le=2147483648),
    Doc(
        "A Virtual Circuit ID, the upper limit comes from the highest number that a service ID could be in Nokia srOS."
    ),
]
