import pytest
from pydantic_forms.exceptions import FormValidationError

from gso.services.partners import get_partner_by_name
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.workflow()
def test_create_partner_success():
    result, _, _ = run_workflow(
        "task_create_partners",
        [
            {
                "name": "GEANT-TEST-CREATION",
                "email": "goat-test-creation@geant.org",
            }
        ],
    )
    assert_complete(result)
    state = extract_state(result)

    partner = get_partner_by_name(state["name"])
    assert partner["name"] == "GEANT-TEST-CREATION"
    assert partner["email"] == "goat-test-creation@geant.org"


@pytest.mark.workflow()
def test_create_partner_with_invalid_input_fails():
    with pytest.raises(FormValidationError) as error:
        run_workflow(
            "task_create_partners",
            [
                {
                    "name": "Kenneth Boyle",
                    "email": "invalid_email",
                }
            ],
        )

    errors = error.value.errors

    email_error = errors[0]
    assert email_error["loc"] == ("email",)
    assert "valid email address" in email_error["msg"]


def test_create_partner_with_duplicate_name_or_email_fails(partner_factory):
    partner_factory(
        name="new_name",
        email="myemail@gmail.com",
    )

    with pytest.raises(FormValidationError) as error:
        run_workflow(
            "task_create_partners",
            [
                {
                    "name": "NEW_name",
                    "email": "myemail@gmail.com",
                }
            ],
        )

    assert error.value.errors[0]["msg"] == "Partner with this name already exists."
    assert error.value.errors[1]["msg"] == "Partner with this email already exists."
